[−][src]Enum indyrs::future::Loop
The status of a loop_fn loop.
Variants
Break(T)Indicates that the loop has completed with output T.
Continue(S)Indicates that the loop function should be called again with input
state S.